=============
*pypowerline*
=============

.. image:: https://img.shields.io/pypi/v/pypowerline

.. image:: https://img.shields.io/github/license/veltzer/pypowerline

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pypowerline

author: Mark Veltzer

version: 0.0.17

	Mark Veltzer <mark.veltzer@gmail.com>, Copyright © 2023
